from .kwargs_utils import *
def getWidget(parent_layout: QVBoxLayout, **wkwargs):
    """Add either (label + widget) or a nested layout into parent_layout."""
    label = wkwargs['label']
    widget = wkwargs['widget']
    nested = wkwargs['nested_layout']
    stretch = wkwargs['stretch']

    if nested is not None:
        parent_layout.addLayout(nested, stretch)
    else:
        if label:
            parent_layout.addWidget(QLabel(label), stretch)  # stretch must be positional
        parent_layout.addWidget(widget, stretch)

def getListBox(*triplets, layout=None):
    layout = layout or QVBoxLayout()
    for t in triplets:
        wkwargs = createWidgetKwargs(*t)
        getWidget(layout, **wkwargs)
    return layout
def getQHBox(*triplets, label=None,layout=None):
    layout = layout or QHBoxLayout()
    label= label or 'QHBOX'
    layout.addStretch(1)
    layout.addWidget(QLabel(label))
    for t in triplets:
        layout.addWidget( t)
    return layout
def getRow(*columns, layout=None):
    layout = layout or QHBoxLayout()
    for col in columns:
        layout.addLayout(col, 1)
    return layout
def getRadioButton(self,label,group,checked=True,func = None):
    label=label or "radio"
    rbutton = QRadioButton(label)
    group.addButton(rbutton)
    self.rbutton.setChecked(checked)
    group = QButtonGroup(self)
    self.rbutton.toggled.connect(func)
    return self.rbutton



#!/usr/bin/env python3
from typing import *
from functools import partial
from abstract_gui.QT6 import build_linked_combos
from abstract_apis import getRequest, postRequest
from abstract_utilities import eatAll
from abstract_utilities.type_utils import MIME_TYPES
from PyQt6.QtGui import QTextCursor # add this import
from PyQt6.QtCore import (
    Qt, QObject, QThread, pyqtSignal, qInstallMessageHandler,
    QtMsgType
)
from PyQt6.QtWidgets import (
    QLabel, QListView, QCompleter, QComboBox, QSizePolicy,
    QApplication, QHBoxLayout, QVBoxLayout, QCheckBox, QWidget,
    QPushButton, QMessageBox, QAbstractItemView, QLineEdit,
    QTextEdit, QTableWidget, QTableWidgetItem, QHeaderView,
    QHBoxLayout, QVBoxLayout, QGridLayout, QFormLayout
    )
import os,re,subprocess,sys,re,traceback,pydot, enum, inspect, sys, traceback, threading,json,traceback,logging,requests
from abstract_utilities import is_number,make_list,safe_read_from_json,read_from_file,make_dirs
from abstract_paths import invert_to_function_map,start_analyzer
from functools import partial, lru_cache



from ..imports import start_analyzer,pydot,os,safe_read_from_json,make_dirs
BASE_DIRECTORY = '/var/www/html/clownworld/bolshevid'
DATA_DIR = make_dirs(BASE_DIRECTORY,"data")
IMPORT_MAP_DIR = make_dirs(DATA_DIR,"import_tools")

def get_dot_path():
    return os.path.join(IMPORT_MAP_DIR,'graph.dot')
def get_import_graph_path():
    return os.path.join(IMPORT_MAP_DIR,'import-graph.json')
def read_from_dot_file(path = None):
    path = get_dot_path()
    graphs, = pydot.graph_from_dot_file(path)
    return graphs
def get_dot_data():
    dot_path = get_dot_path()
    ensure_import_creation(dot_path)
    return read_from_dot_file()
def get_import_graph_data():
    graph_path = get_import_graph_path()
    ensure_import_creation(graph_path)
    return safe_read_from_json(graph_path)
def ensure_import_creation(path):
    if not os.path.isfile(path):
        create_import_maps()
def create_import_maps():
    root = BASE_DIRECTORY
    directory = os.getcwd()
    entries = 'index,main'
    out = get_import_graph_path()
    dot = get_dot_path()
    start_analyzer(root=root,entries=entries,out=out,dot=dot)
